@@ -152,11 +152,13 @@ class visualize:
         __graph(stock)
         plt.show()
 
-    @staticmethod
-    def graph_candlestick_analysis(stocks, cache=True):
+    @classmethod
+    def graph_candlestick_analysis(cls, stocks, cache=True, rangeslider=True, span='max'):
         """Takes in a list of Ticker Symbols and optional span. Displays a matplot graph with the history of that stock, default span to one day
         :param stock: list of Stock objects
         :type stock: list [<stock_wrapper.Stock>]
+        :param cache: Whether to cache data in __stock_cache__
+        :type cache: bool
         :param span: how far back the graph should span for
         :type span: str, ['day', 'week', 'month', '3month', 'year']
         """
@@ -172,20 +174,22 @@ class visualize:
             fig.add_trace(go.Scatter(x=data['Date'], y=data['200_SMA'], name='200 Day Moving Average', marker_color='rgba(255, 165, 0, .8)'))
             fig.add_trace(go.Scatter(x=data['Date'], y=data['Volume'], name='Volume', marker_color='rgba(130, 178, 255, .8)'), secondary_y=True)
 
+            fig.update_layout(xaxis_rangeslider_visible=rangeslider)
+
             fig.show()
 
-        data = []
-        for stock in stocks:
-            data.append(stock_wrapper.data.get_history(stock.ticker, calculate_averages=True, cache=cache))
+        data = cls.__load_data(stocks, span, cache=cache)
 
         for i in range(len(data)):
             __graph(stocks[i], data[i])
 
-    @staticmethod
-    def graph_trendline_analysis(stocks, cache=True):
+    @classmethod
+    def graph_trendline_analysis(cls, stocks, cache=True, span='max'):
         """Takes in a list of Ticker Symbols and optional span. Displays a matplot graph with the history of that stock, default span to one day
         :param stock: list of Stock objects
         :type stock: list [<stock_wrapper.Stock>]
+        :param cache: cache the value in __stock_cache__ folder
+        :type cache: bool
         :param span: how far back the graph should span for
         :type span: str, ['day', 'week', 'month', '3month', 'year']
         """
@@ -194,29 +198,25 @@ class visualize:
             sns.set(style="darkgrid")
 
             plt.figure()
-            ax = sns.lineplot(x="Date", y="High", color='#82b2ff', data=data)
-            sns.lineplot(x="Date", y="Low", color='#82b2ff', data=data)
-            sns.lineplot(x="Date", y="10_SMA", color='#0d5ad6', data=data)
-            sns.lineplot(x="Date", y="20_SMA", color='#e6df17', data=data)
-            sns.lineplot(x="Date", y="100_SMA", color='#fc7b03', data=data)
-            sns.lineplot(x="Date", y="200_SMA", color='#ffa500', data=data)
+            ax = sns.lineplot(x='Date', y="Close", color='#82b2ff', data=data)
+            sns.lineplot(x='Date', y="10_SMA", color='#0d5ad6', data=data)
+            sns.lineplot(x='Date', y="20_SMA", color='#e6df17', data=data)
+            sns.lineplot(x='Date', y="100_SMA", color='#ffa500', data=data)
+            sns.lineplot(x='Date', y="200_SMA", color='#fc7b03', data=data)
 
-            average_patch = mpatches.Patch(color='#82b2ff', label='High Price')
-            average_patch = mpatches.Patch(color='#82b2ff', label='Low Price')
+            close_patch = mpatches.Patch(color='#82b2ff', label='Close Price')
             sma_10_patch = mpatches.Patch(color='#0d5ad6', label='10 Day Moving Average')
             sma_20_patch = mpatches.Patch(color='#e6df17', label='20 Day Moving Average')
-            sma_100_patch = mpatches.Patch(color='#fc7b03', label='100 Day Moving Average')
-            sma_200_patch = mpatches.Patch(color='#ffa500', label='200 Day Moving Average')
-            plt.legend(handles=[average_patch, sma_10_patch, sma_20_patch, sma_100_patch, sma_200_patch])
+            sma_100_patch = mpatches.Patch(color='#ffa500', label='100 Day Moving Average')
+            sma_200_patch = mpatches.Patch(color='#fc7b03', label='200 Day Moving Average')
+            plt.legend(handles=[close_patch, sma_10_patch, sma_20_patch, sma_100_patch, sma_200_patch])
 
             ax.set_title(stock.ticker)
             plt.gcf().canvas.set_window_title(stock.ticker)
             plt.xlabel("Date")
             plt.ylabel("Price ($)")
 
-        data = []
-        for stock in stocks:
-            data.append(stock_wrapper.data.get_history(stock.ticker, calculate_averages=True, cache=cache))
+        data = cls.__load_data(stocks, span, cache=cache)
 
         for i in range(len(data)):
             __graph(stocks[i], data[i])
@@ -224,12 +224,12 @@ class visualize:
         plt.show()
 
     @staticmethod
-    def graph_stocks(stock_objects, span='day'):
+    def graph_stocks(stock_objects, span='week'):
         """Takes in a list of and optional span. Displays a matplot graph with the history of that stock, default span to one day
-        :param stock: list of Stock objects
-        :type stock: list <stock_wrapper.Stock>
+        :param stock_objects: list of Stock objects
+        :type stock_objects: list <stock_wrapper.Stock>
         :param span: how far back the graph should span for
-        :type span: str, ['day', 'week', 'month', '3month', 'year']
+        :type span: str, [day, week, month, 3month, year, max]
         """
 
         f, axes = plt.subplots(int(np.ceil(len(stock_objects) / 3)), 3, figsize=(8, 6))
@@ -257,4 +257,26 @@ class visualize:
         sns.despine(left=True)
         sns.set(style="dark")
 
-        plt.show()
\ No newline at end of file
+        plt.show()
+
+    @staticmethod
+    def __load_data(stocks, span, cache=True):
+        converter = {'week': '1m', 'month':'30m', 'max': '1d'}
+
+        # def __gather_data(i, list, symbol):
+        #     list[i] = stock_wrapper.data.get_history(symbol, span='week', interval=converter[span], cache=cache)
+        #
+        # threads = []
+        histories = []
+        # for i in range(len(stocks)):
+        #     thread = threading.Thread(target=__gather_data, args=(i, histories, stocks[i].ticker))
+        #     threads.append(thread)
+        #     thread.start()
+        #
+        # for thread in threads:
+        #     thread.join()
+
+        for stock in stocks:
+            histories.append(stock_wrapper.data.get_history(stock.ticker, span=span, interval=converter[span], cache=cache))
+
+        return histories
\ No newline at end of file
